django_analyses package — django_analyses 0.0.3 documentation

# django_analyses package

## Subpackages

- django_analyses.filters package
  - Subpackages
    - django_analyses.filters.input package
    - django_analyses.filters.output package
    - django_analyses.filters.pipeline package
  - Submodules
  - django_analyses.filters.analysis module
  - django_analyses.filters.category module
  - Module contents
- django_analyses.migrations package
  - Submodules
  - django_analyses.migrations.0001_initial module
  - Module contents
- django_analyses.models package
  - Subpackages
    - django_analyses.models.input package
    - django_analyses.models.managers package
    - django_analyses.models.output package
    - django_analyses.models.pipeline package
  - Submodules
  - django_analyses.models.analysis module
  - django_analyses.models.analysis_version module
  - django_analyses.models.category module
  - django_analyses.models.run module
  - Module contents
- django_analyses.serializers package
  - Subpackages
    - django_analyses.serializers.input package
    - django_analyses.serializers.output package
    - django_analyses.serializers.pipeline package
    - django_analyses.serializers.utils package
  - Submodules
  - django_analyses.serializers.analysis module
  - django_analyses.serializers.analysis_version module
  - django_analyses.serializers.category module
  - django_analyses.serializers.run module
  - Module contents
- django_analyses.utils package
  - Submodules
  - django_analyses.utils.choice_enum module
  - django_analyses.utils.input_manager module
  - django_analyses.utils.output_manager module
  - Module contents
- django_analyses.views package
  - Submodules
  - django_analyses.views.analysis module
  - django_analyses.views.analysis_version module
  - django_analyses.views.category module
  - django_analyses.views.defaults module
  - django_analyses.views.input module
  - django_analyses.views.input_definition module
  - django_analyses.views.input_specification module
  - django_analyses.views.node module
  - django_analyses.views.output module
  - django_analyses.views.output_definition module
  - django_analyses.views.output_specification module
  - django_analyses.views.pagination module
  - django_analyses.views.pipe module
  - django_analyses.views.pipeline module
  - django_analyses.views.run module
  - Module contents

## Submodules

## django_analyses.admin module

class `django_analyses.admin.` `AnalysisAdmin`(model, admin_site)

  Bases: `django.contrib.admin.options.ModelAdmin`

  `inlines` = [<class 'django_analyses.admin.AnalysisVersionInline'>]
  `list_display` = ('title', 'description', 'created', 'modified')
  property `media`

class `django_analyses.admin.` `AnalysisVersionAdmin`(model, admin_site)

  Bases: `django.contrib.admin.options.ModelAdmin`

  `fieldsets` = ((None, {'fields': ('analysis', 'title', 'description')}), ('Advanced Options', {'classes': ('collapse',), 'fields': ('run_method_key', 'nested_results_attribute')}))
  property `media`
  `name`(instance) → str

class `django_analyses.admin.` `AnalysisVersionInline`(parent_model, admin_site)

  Bases: `django.contrib.admin.options.TabularInline`

  property `media`
  `model`

    alias of `django_analyses.models.analysis_version.AnalysisVersion`

class `django_analyses.admin.` `InputAdmin`(model, admin_site)

  Bases: `django.contrib.admin.options.ModelAdmin`

  `analysis_version`(instance) → str
  `get_queryset`(request)

    Return a QuerySet of all model instances that can be edited by the admin site. This is used by changelist_view.

  `list_display` = ('run_id', 'key', 'value', 'analysis_version')
  `list_display_links` = None
  `list_filter` = ('run__analysis_version',)
  property `media`
  `run_id`(instance) → str
  `search_fields` = ('run__id',)

class `django_analyses.admin.` `InputDefinitionAdmin`(model, admin_site)

  Bases: `django.contrib.admin.options.ModelAdmin`

  `choices`(instance) → list
  `get_queryset`(request)

    Return a QuerySet of all model instances that can be edited by the admin site. This is used by changelist_view.

  `list_display` = ('key', 'description', 'min_value', 'max_value', 'default', 'choices', 'required', 'is_configuration')
  `list_filter` = ('specification_set__analysis__title', 'specification_set__id')
  `max_value`(instance)
  property `media`
  `min_value`(instance)

class `django_analyses.admin.` `InputDefinitionsInline`(parent_model, admin_site)

  Bases: `django.contrib.admin.options.TabularInline`

  property `media`
  `model`

    alias of `django_analyses.models.input.input_specification.InputSpecification_base_input_definitions`

  `verbose_name_plural` = 'Input Definitions'

class `django_analyses.admin.` `InputInline`(parent_model, admin_site)

  Bases: `django.contrib.admin.options.TabularInline`

  `extra` = 0
  `get_queryset`(request)

    Return a QuerySet of all model instances that can be edited by the admin site. This is used by changelist_view.

  property `media`
  `model`

    alias of `django_analyses.models.input.input.Input`

  `readonly_fields` = ('key', 'value')

class `django_analyses.admin.` `InputSpecificationAdmin`(model, admin_site)

  Bases: `django.contrib.admin.options.ModelAdmin`

  `fields` = ('analysis',)
  `inlines` = [<class 'django_analyses.admin.InputDefinitionsInline'>]
  `list_display` = ('id', 'analysis')
  `list_filter` = ('analysis',)
  property `media`

class `django_analyses.admin.` `OutputAdmin`(model, admin_site)

  Bases: `django.contrib.admin.options.ModelAdmin`

  `analysis_version`(instance) → str
  `get_queryset`(request)

    Return a QuerySet of all model instances that can be edited by the admin site. This is used by changelist_view.

  `list_display` = ('run_id', 'key', 'value', 'analysis_version')
  `list_display_links` = None
  `list_filter` = ('run__analysis_version', 'run__id')
  property `media`
  `run_id`(instance) → str

class `django_analyses.admin.` `OutputDefinition`(model, admin_site)

  Bases: `django.contrib.admin.options.ModelAdmin`

  `analysis`(instance)
  `list_display` = ('key', 'description', 'analysis')
  `list_filter` = ('specification_set__analysis__title', 'specification_set__id')
  property `media`

class `django_analyses.admin.` `OutputInline`(parent_model, admin_site)

  Bases: `django.contrib.admin.options.TabularInline`

  `extra` = 0
  `get_queryset`(request)

    Return a QuerySet of all model instances that can be edited by the admin site. This is used by changelist_view.

  property `media`
  `model`

    alias of `django_analyses.models.output.output.Output`

  `readonly_fields` = ('key', 'value')

class `django_analyses.admin.` `OutputSpecificationAdmin`(model, admin_site)

  Bases: `django.contrib.admin.options.ModelAdmin`

  `fields` = ('analysis',)
  `list_display` = ('id', 'analysis')
  `list_filter` = ('analysis',)
  property `media`

class `django_analyses.admin.` `RunAdmin`(model, admin_site)

  Bases: `django.contrib.admin.options.ModelAdmin`

  class `Media`

    Bases: `object`

    `css` = {'all': ('django_analyses/css/hide_admin_original.css',)}
  `inlines` = (<class 'django_analyses.admin.InputInline'>, <class 'django_analyses.admin.OutputInline'>)
  `list_display` = ('id', 'analysis_version', 'created')
  property `media`

## django_analyses.apps module

class `django_analyses.apps.` `DjangoAnalysesConfig`(app_name, app_module)

  Bases: `django.apps.config.AppConfig`

  `name` = 'django_analyses'

## django_analyses.pipeline_runner module

class `django_analyses.pipeline_runner.` `PipelineRunner`(pipeline: django_analyses.models.pipeline.pipeline.Pipeline)

  Bases: `object`

  `get_destination_kwarg`(pipe: django_analyses.models.pipeline.pipe.Pipe) → dict
  `get_incoming_pipes`(node: django_analyses.models.pipeline.node.Node) → django.db.models.query.QuerySet
  `get_node_inputs`(node: django_analyses.models.pipeline.node.Node) → dict
  `has_required_runs`(node: django_analyses.models.pipeline.node.Node) → bool
  property `pending_nodes`
  `run`(inputs: dict)
  `run_entry_nodes`(inputs: dict) → None
  `run_node`(node: django_analyses.models.pipeline.node.Node) → None

## django_analyses.urls module

## Module contents